package com.hchyun.test.service;

import java.util.List;

import com.hchyun.common.utils.ServerResult;
import com.hchyun.test.entity.Stu;

/**
 * 学生Service接口
 *
 * @author hchyun
 * @date 2021-01-23
 */
public interface StuService {
    /**
     * 查询学生
     *
     * @param id 学生ID
     * @return 学生
     */
    ServerResult<Stu> selectStuById(Long id);

    /**
     * 查询学生列表
     *
     * @param stu 学生
     * @return 学生集合
     */
    ServerResult<List<Stu>> selectStuList(Stu stu);

    /**
     * 新增学生
     *
     * @param stu 学生
     * @return 结果
     */
    ServerResult<Integer> insertStu(Stu stu);

    /**
     * 修改学生
     *
     * @param stu 学生
     * @return 结果
     */
    ServerResult<Integer> updateStu(Stu stu);

    /**
     * 批量删除学生
     *
     * @param ids 需要删除的学生ID
     * @return 结果
     */
    ServerResult<Integer> deleteStuByIds(Long[] ids);

    /**
     * 删除学生信息
     *
     * @param id 学生ID
     * @return 结果
     */
    ServerResult<Integer> deleteStuById(Long id);
}
